<?php
namespace plugins\contactform\controllers;

use \Validator;

/**
 * Settings controller
 * @author Jérôme Brilland
 * @version 2.1
 * @copyright (c) 2021-2022, Jérôme Brilland
 * @license http://www.gnu.org/licenses/gpl.txt GNU General Public License
 */
class SettingsController extends \ActionController {

    protected function beforeFilter() {
        $authorization = \IoC::resolve( 'authorization' );
        $authorization->authorize( 'manage_settings' );
    }

    public function doIndex() {
        $settings = \IoC::resolve( 'settings' );
        $i18n = \IoC::resolve( 'i18n' );
        $this->title = $i18n->__( 'settings' );
        $this->email = $settings['contactform.to_email'];
        $this->render( 'settingsform.html' );
    }

    public function doUpdate() {
        if ( !Validator::validateEmail( $this->request->getParameter( 'email' ) ) ) {
            $this->flash['error'] = \IoC::resolve( 'i18n' )->__( 'invalid_email' );
            $this->redirect( BASE_URL . 'contact/settings' );
        }
        $configurationHandler = \IoC::resolve( 'databaseConfigurationHandler');
        $settings = new \Configuration( $configurationHandler );
        $settings['contactform.to_email'] = $this->request->getParameter( 'email' );
        $configurationHandler->save();
        $this->flash['success'] = \IoC::resolve( 'i18n' )->__( 'settings_successfully_updated' );
        $this->redirect( BASE_URL . 'contact/settings' );
    }
}
